@@ -9,7 +9,7 @@ use vars qw( $VERSION $DEBUG @ISA @EXPORT_OK );
 @EXPORT_OK = qw( csv );
 
 BEGIN {
-    $VERSION = '1.91';
+    $VERSION = '1.92';
     $DEBUG   = 0;
 }
 
@@ -969,6 +969,9 @@ argument.
 You may use the L</types>  method for setting column types.  See L</types>'
 description below.
 
+The C<$line> argument is supposed to be a simple scalar. Everything else is
+supposed to croak and set error 1500.
+
 =head2 fragment
 
 This function tries to implement RFC7111  (URI Fragment Identifiers for the
@@ -2244,6 +2247,12 @@ X<1014>
 
 The header line cannot be parsed from an undefined sources.
 
+=item *
+1500 "PRM - Invalid/unsupported argument(s)"
+X<1500>
+
+Function or method called with invalid argument(s) or parameter(s).
+
 =item *
 2010 "ECR - QUO char inside quotes followed by CR not part of EOL"
 X<2010>
@@ -2426,7 +2435,8 @@ completed the documentation, fixed some RT bugs. See ChangeLog releases
 Makamaka Hannyaharamitu, E<lt>makamaka[at]cpan.orgE<gt> wrote Text::CSV_PP
 which is the pure-Perl version of Text::CSV_XS.
 
-New Text::CSV (since 0.99) is maintained by Makamaka.
+New Text::CSV (since 0.99) is maintained by Makamaka, and Kenichi Ishigaki
+since 1.91.
 
 
 =head1 COPYRIGHT AND LICENSE
@@ -2435,16 +2445,18 @@ Text::CSV
 
 Copyright (C) 1997 Alan Citterman. All rights reserved.
 Copyright (C) 2007-2015 Makamaka Hannyaharamitu.
-
+Copyright (C) 2017- Kenichi Ishigaki
+A large portion of the doc is taken from Text::CSV_XS. See below.
 
 Text::CSV_PP:
 
 Copyright (C) 2005-2015 Makamaka Hannyaharamitu.
-
+Copyright (C) 2017- Kenichi Ishigaki
+A large portion of the code/doc are also taken from Text::CSV_XS. See below.
 
 Text:CSV_XS:
 
-Copyright (C) 2007-2015 H.Merijn Brand for PROCURA B.V.
+Copyright (C) 2007-2016 H.Merijn Brand for PROCURA B.V.
 Copyright (C) 1998-2001 Jochen Wiedmann. All rights reserved.
 Portions Copyright (C) 1997 Alan Citterman. All rights reserved.
 
